@@ -189,23 +189,9 @@ gdict_defbox_dispose (GObject *gobject)
       priv->buffer = NULL;
     }
 
-  if (priv->busy_cursor)
-    {
-      gdk_cursor_unref (priv->busy_cursor);
-      priv->busy_cursor = NULL;
-    }
-
-  if (priv->hand_cursor)
-    {
-      gdk_cursor_unref (priv->hand_cursor);
-      priv->hand_cursor = NULL;
-    }
-
-  if (priv->regular_cursor)
-    {
-      gdk_cursor_unref (priv->regular_cursor);
-      priv->regular_cursor = NULL;
-    }
+  g_clear_object (&priv->busy_cursor);
+  g_clear_object (&priv->hand_cursor);
+  g_clear_object (&priv->regular_cursor);
 
   G_OBJECT_CLASS (gdict_defbox_parent_class)->dispose (gobject);
 }
@@ -2047,7 +2033,7 @@ gdict_defbox_set_database (GdictDefbox *defbox,
  *
  * Since: 0.1
  */
-G_CONST_RETURN gchar *
+const gchar *
 gdict_defbox_get_database (GdictDefbox *defbox)
 {
   g_return_val_if_fail (GDICT_IS_DEFBOX (defbox), NULL);
@@ -2067,7 +2053,7 @@ gdict_defbox_get_database (GdictDefbox *defbox)
  *
  * Since: 0.12
  */
-G_CONST_RETURN gchar *
+const gchar *
 gdict_defbox_get_word (GdictDefbox *defbox)
 {
   g_return_val_if_fail (GDICT_IS_DEFBOX (defbox), NULL);
@@ -2853,7 +2839,11 @@ gdict_defbox_set_font_name (GdictDefbox *defbox,
   else
     font_desc = NULL;
 
+#if GTK_CHECK_VERSION (2, 91, 6)
+  gtk_widget_override_font (priv->text_view, font_desc);
+#else
   gtk_widget_modify_font (priv->text_view, font_desc);
+#endif
 
   if (font_desc)
     pango_font_description_free (font_desc);
@@ -2873,7 +2863,7 @@ gdict_defbox_set_font_name (GdictDefbox *defbox,
  *
  * Since: 0.3
  */
-G_CONST_RETURN gchar *
+const gchar *
 gdict_defbox_get_font_name (GdictDefbox *defbox)
 {
   g_return_val_if_fail (GDICT_IS_DEFBOX (defbox), NULL);
