@@ -46,12 +46,14 @@
 #include "screenshot-save.h"
 #include "screenshot-dialog.h"
 #include "screenshot-xfer.h"
+#include "cheese-flash.h"
 
 #define SCREENSHOOTER_ICON "applets-screenshooter"
 
 #define GNOME_SCREENSHOT_SCHEMA "org.gnome.gnome-screenshot"
 #define INCLUDE_BORDER_KEY      "include-border"
 #define INCLUDE_POINTER_KEY     "include-pointer"
+#define INCLUDE_ICC_PROFILE     "include-icc-profile"
 #define LAST_SAVE_DIRECTORY_KEY "last-save-directory"
 #define BORDER_EFFECT_KEY       "border-effect"
 #define DELAY_KEY               "delay"
@@ -96,19 +98,21 @@ static char *window_title = NULL;
 static char *temporary_file = NULL;
 static gboolean save_immediately = FALSE;
 static GSettings *settings = NULL;
+static CheeseFlash *flash = NULL;
 
 /* Options */
 static gboolean take_window_shot = FALSE;
 static gboolean take_area_shot = FALSE;
 static gboolean include_border = FALSE;
 static gboolean include_pointer = TRUE;
+static gboolean include_icc_profile = TRUE;
 static char *border_effect = NULL;
 static guint delay = 0;
 
 /* some local prototypes */
 static void  display_help           (GtkWindow *parent);
 static void  save_done_notification (gpointer   data);
-static char *get_desktop_dir        (void);
+static char *get_screenshot_dir     (void);
 static void  save_options           (void);
 
 static GtkWidget *border_check = NULL;
@@ -803,9 +807,72 @@ play_sound_effect (GdkWindow *window)
 
 }
 
+static gchar *
+get_profile_for_window (GdkWindow *window)
+{
+  gboolean ret = FALSE;
+  GDBusConnection *connection;
+  GError *error = NULL;
+  guint xid;
+  gchar *icc_profile = NULL;
+  GVariant *args = NULL;
+  GVariant *response = NULL;
+  GVariant *response_child = NULL;
+  GVariantIter *iter = NULL;
+
+  /* get a session bus connection */
+  connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  if (connection == NULL)
+    {
+      g_debug ("Failed to connect to session bus: %s", error->message);
+      g_error_free (error);
+      goto out;
+    }
+
+  /* get color profile */
+  xid = GDK_WINDOW_XID (window);
+  args = g_variant_new ("(u)", xid),
+  response = g_dbus_connection_call_sync (connection,
+                                          "org.gnome.ColorManager",
+                                          "/org/gnome/ColorManager",
+                                          "org.gnome.ColorManager",
+                                          "GetProfileForWindow",
+                                          args,
+                                          G_VARIANT_TYPE ("(s)"),
+                                          G_DBUS_CALL_FLAGS_NONE,
+                                          -1, NULL, &error);
+  if (response == NULL)
+    {
+      /* not a warning, as GCM might not be installed / running */
+      g_debug ("The GetProfileForWindow request failed: %s",
+               error->message);
+      g_error_free (error);
+      goto out;
+    }
+
+  /* get icc profile filename */
+  response_child = g_variant_get_child_value (response, 0);
+  icc_profile = g_variant_dup_string (response_child, NULL);
+out:
+  if (iter != NULL)
+    g_variant_iter_free (iter);
+  if (args != NULL)
+    g_variant_unref (args);
+  if (response != NULL)
+    g_variant_unref (response);
+  return icc_profile;
+}
+
 static void
 finish_prepare_screenshot (char *initial_uri, GdkWindow *window, GdkRectangle *rectangle)
 {  
+  char *icc_profile_filename;
+  guchar *icc_profile;
+  gsize icc_profile_size;
+  char *icc_profile_base64;
+  gboolean ret;
+  GError *error = NULL;
+  GdkRectangle rect;
   ScreenshotDialog *dialog;
 
   /* always disable window border for full-desktop or selected-area screenshots */
@@ -840,11 +907,49 @@ finish_prepare_screenshot (char *initial_uri, GdkWindow *window, GdkRectangle *r
       exit (1);
     }
 
+  flash = cheese_flash_new ();
+
+  if (rectangle != NULL)
+    rect = *rectangle;
+  else
+    screenshot_get_window_rect (window, &rect);
+
+  cheese_flash_fire (flash, &rect);
   play_sound_effect (window);
 
   dialog = screenshot_dialog_new (screenshot, initial_uri, take_window_shot);
   g_free (initial_uri);
 
+  /* load ICC profile */
+  if (include_icc_profile)
+    {
+      icc_profile_filename = get_profile_for_window (window);
+      if (icc_profile_filename != NULL)
+        {
+          ret = g_file_get_contents (icc_profile_filename,
+                                     (gchar **) &icc_profile,
+                                     &icc_profile_size,
+                                     &error);
+          if (ret)
+            {
+              icc_profile_base64 = g_base64_encode (icc_profile,
+                                                    icc_profile_size);
+
+              /* use this profile for saving the image */
+              screenshot_set_icc_profile (icc_profile_base64);
+              g_free (icc_profile);
+              g_free (icc_profile_base64);
+            }
+          else
+            {
+              g_warning ("could not open ICC file: %s",
+                         error->message);
+              g_error_free (error);
+            }
+          g_free (icc_profile_filename);
+        }
+    }
+
   screenshot_save_start (screenshot, save_done_notification, dialog);
 
   run_dialog (dialog);
@@ -858,7 +963,10 @@ async_existence_job_free (AsyncExistenceJob *job)
 
   g_free (job->base_uris[1]);
   g_free (job->base_uris[2]);
-  g_free (job->rectangle);
+
+  if (job->rectangle != NULL)
+    g_slice_free (GdkRectangle, job->rectangle);
+
   g_slice_free (AsyncExistenceJob, job);
 }
 
@@ -878,43 +986,33 @@ static char *
 build_uri (AsyncExistenceJob *job)
 {
   char *retval, *file_name;
+  char *timestamp;
+  GDateTime *d;
 
-  if (window_title)
+  d = g_date_time_new_now_local ();
+  /* Translators: This is a strftime format string.
+		 * It is used to display the time in 24-hours format (eg, like
+		 * in France: 20:10). */
+  timestamp = g_date_time_format (d, _("%Y-%m-%d %H:%M:%S"));
+  g_date_time_unref (d);
+
+  if (job->iteration == 0)
     {
       /* translators: this is the name of the file that gets made up
-       * with the screenshot if a specific window is taken */
-      if (job->iteration == 0)
-        {
-          file_name = g_strdup_printf (_("Screenshot-%s.png"), window_title);
-        }
-      else
-        {
-          /* translators: this is the name of the file that gets
-           * made up with the screenshot if a specific window is
-           * taken */
-          file_name = g_strdup_printf (_("Screenshot-%s-%d.png"),
-                                       window_title, job->iteration);
-        }
+       * with the screenshot if the entire screen is taken */
+      file_name = g_strdup_printf (_("Screenshot at %s.png"), timestamp);
     }
   else
     {
-      if (job->iteration == 0)
-        {
-          /* translators: this is the name of the file that gets made up
-           * with the screenshot if the entire screen is taken */
-          file_name = g_strdup (_("Screenshot.png"));
-        }
-      else
-        {
-          /* translators: this is the name of the file that gets
-           * made up with the screenshot if the entire screen is
-           * taken */
-          file_name = g_strdup_printf (_("Screenshot-%d.png"), job->iteration);
-        }
+      /* translators: this is the name of the file that gets
+       * made up with the screenshot if the entire screen is
+       * taken */
+      file_name = g_strdup_printf (_("Screenshot at %s - %d.png"), timestamp, job->iteration);
     }
 
   retval = g_build_filename (job->base_uris[job->type], file_name, NULL);
   g_free (file_name);
+  g_free (timestamp);
 
   return retval;
 }
@@ -1048,44 +1146,28 @@ find_current_window (char **window_title)
   return window;
 }
 
-static GdkRectangle *
-find_rectangle (void)
-{
-  GdkRectangle *rectangle;
-
-  if (!take_area_shot)
-    return NULL;
-
-  rectangle = g_new0 (GdkRectangle, 1);
-  if (screenshot_select_area (&rectangle->x, &rectangle->y,
-                              &rectangle->width, &rectangle->height))
-    {
-      g_assert (rectangle->width >= 0);
-      g_assert (rectangle->height >= 0);
-
-      return rectangle;
-    }
-  else
-    {
-      g_free (rectangle);
-      return NULL;
-    }
-}
-
 static void
-prepare_screenshot (void)
-{
+push_check_file_job (GdkRectangle *rectangle)
+{ 
   AsyncExistenceJob *job;
-  
+
   job = g_slice_new0 (AsyncExistenceJob);
   job->base_uris[0] = last_save_dir;
   /* we'll have to free these two */
-  job->base_uris[1] = get_desktop_dir ();
+  job->base_uris[1] = get_screenshot_dir ();
   job->base_uris[2] = g_strconcat ("file://", g_get_tmp_dir (), NULL);
   job->iteration = 0;
   job->type = TEST_LAST_DIR;
   job->window = find_current_window (&window_title);
-  job->rectangle = find_rectangle ();
+
+  if (rectangle != NULL)
+    {
+      job->rectangle = g_slice_new0 (GdkRectangle);
+      job->rectangle->x = rectangle->x;
+      job->rectangle->y = rectangle->y;
+      job->rectangle->width = rectangle->width;
+      job->rectangle->height = rectangle->height;
+    }
 
   /* Check if the area selection was cancelled */
   if (job->rectangle &&
@@ -1100,7 +1182,21 @@ prepare_screenshot (void)
                            job,
                            NULL,
                            0, NULL);
-                           
+}
+
+static void
+rectangle_found_cb (GdkRectangle *rectangle)
+{
+  push_check_file_job (rectangle);
+}
+
+static void
+prepare_screenshot (void)
+{
+  if (take_area_shot)
+    screenshot_select_area_async (rectangle_found_cb);
+  else
+    push_check_file_job (NULL);
 }
 
 static gboolean
@@ -1114,23 +1210,13 @@ prepare_screenshot_timeout (gpointer data)
 
 
 static gchar *
-get_desktop_dir (void)
+get_screenshot_dir (void)
 {
-  GSettings *nautilus_prefs;
-  gboolean desktop_is_home_dir = FALSE;
-  gchar *desktop_dir;
+  gchar *shot_dir;
 
-  nautilus_prefs = g_settings_new ("org.gnome.nautilus.preferences");
-  desktop_is_home_dir = g_settings_get_boolean (nautilus_prefs, "desktop-is-home-dir");
+  shot_dir = g_strconcat ("file://", g_get_user_special_dir (G_USER_DIRECTORY_PICTURES), NULL);
 
-  if (desktop_is_home_dir)
-    desktop_dir = g_strconcat ("file://", g_get_home_dir (), NULL);
-  else
-    desktop_dir = g_strconcat ("file://", g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP), NULL);
-
-  g_object_unref (nautilus_prefs);
-
-  return desktop_dir;
+  return shot_dir;
 }
 
 /* Taken from gnome-vfs-utils.c */
@@ -1172,7 +1258,7 @@ load_options (void)
                                          LAST_SAVE_DIRECTORY_KEY);
   if (!last_save_dir || !last_save_dir[0])
     {
-      last_save_dir = get_desktop_dir ();
+      last_save_dir = get_screenshot_dir ();
     }
   else if (last_save_dir[0] == '~')
     {
@@ -1184,6 +1270,9 @@ load_options (void)
   include_border = g_settings_get_boolean (settings,
                                            INCLUDE_BORDER_KEY);
 
+  include_icc_profile = g_settings_get_boolean (settings,
+                                                INCLUDE_ICC_PROFILE);
+
   include_pointer = g_settings_get_boolean (settings,
                                             INCLUDE_POINTER_KEY);
 
@@ -1202,6 +1291,8 @@ save_options (void)
                           INCLUDE_BORDER_KEY, include_border);
   g_settings_set_boolean (settings,
                           INCLUDE_POINTER_KEY, include_pointer);
+  g_settings_set_boolean (settings,
+                          INCLUDE_ICC_PROFILE, include_icc_profile);
   g_settings_set_int (settings, DELAY_KEY, delay);
   g_settings_set_string (settings,
                          BORDER_EFFECT_KEY, border_effect);
@@ -1351,11 +1442,23 @@ main (int argc, char *argv[])
     }
   else
     {
-      /* start this in an idle anyway and fire up the mainloop */
-      g_idle_add (prepare_screenshot_timeout, NULL);
+      if (interactive_arg)
+        {
+          /* HACK: give time to the dialog to actually disappear.
+           * We don't have any way to tell when the compositor has finished 
+           * re-drawing.
+           */
+          g_timeout_add (200,
+                         prepare_screenshot_timeout, NULL);
+        }
+      else
+        g_idle_add (prepare_screenshot_timeout, NULL);
     }
 
   gtk_main ();
 
+  if (flash != NULL)
+    g_object_unref (flash);
+
   return EXIT_SUCCESS;
 }
