@@ -195,10 +195,6 @@ click_help_cb (GtkWidget * widget,
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 		                                          error->message, NULL);
 
-		gtk_window_set_title (GTK_WINDOW (dialog), "");
-		gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-		gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 		g_signal_connect (G_OBJECT (dialog),
                                   "response",
                                   G_CALLBACK (gtk_widget_destroy), NULL);
@@ -270,7 +266,7 @@ remove_constraint_cb (GtkWidget * widget,
 	                               &gsearch->window_geometry,
 	                               GDK_HINT_MIN_SIZE);
 
-	gtk_container_remove (GTK_CONTAINER (gsearch->available_options_vbox), widget->parent);
+	gtk_container_remove (GTK_CONTAINER (gsearch->available_options_vbox), gtk_widget_get_parent (widget));
 
 	gsearch->available_options_selected_list =
 	    g_list_remove (gsearch->available_options_selected_list, constraint);
@@ -360,12 +356,8 @@ display_dialog_file_open_limit (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          secondary, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	button = gtk_button_new_from_stock ("gtk-open");
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 	gtk_widget_show (button);
 
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
@@ -397,10 +389,6 @@ display_dialog_could_not_open_file (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          message, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	g_signal_connect (G_OBJECT (dialog),
                		  "response",
                		  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -426,10 +414,6 @@ display_dialog_could_not_open_folder (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          _("The nautilus file manager is not running."));
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	g_signal_connect (G_OBJECT (dialog),
                		  "response",
                		  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -493,7 +477,7 @@ open_file_cb (GtkMenuItem * action,
 		if (!no_files_found) {
 			GAppInfo * app = NULL;
 
-			if (GTK_IS_OBJECT (action)) {
+			if (GTK_IS_MENU_ITEM (action)) {
 				app = g_object_get_data (G_OBJECT (action), "app");
 			}
 
@@ -557,12 +541,8 @@ display_dialog_folder_open_limit (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          secondary, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	button = gtk_button_new_from_stock ("gtk-open");
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 	gtk_widget_show (button);
 
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
@@ -702,10 +682,6 @@ display_dialog_could_not_move_to_trash (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          message, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	g_signal_connect (G_OBJECT (dialog),
                		  "response",
                		  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -737,12 +713,8 @@ display_dialog_delete_permanently (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          secondary, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	button = gtk_button_new_from_stock ("gtk-delete");
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 	gtk_widget_show (button);
 
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
@@ -775,10 +747,6 @@ display_dialog_could_not_delete (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          message, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	g_signal_connect (G_OBJECT (dialog),
                		  "response",
                		  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -958,15 +926,15 @@ file_key_press_event_cb (GtkWidget * widget,
                          GdkEventKey * event,
                          gpointer data)
 {
-	if (event->keyval == GDK_space  ||
-	    event->keyval == GDK_Return ||
-	    event->keyval == GDK_KP_Enter) {
+	if (event->keyval == GDK_KEY_space  ||
+	    event->keyval == GDK_KEY_Return ||
+	    event->keyval == GDK_KEY_KP_Enter) {
 		if (event->state != GDK_CONTROL_MASK) {
 			open_file_cb ((GtkMenuItem *) NULL, data);
 			return TRUE;
 		}
 	}
-	else if (event->keyval == GDK_Delete) {
+	else if (event->keyval == GDK_KEY_Delete) {
 		move_to_trash_cb ((GtkAction *) NULL, data);
 		return TRUE;
 	}
@@ -1073,6 +1041,7 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 			/* Popup menu item: Open with (default) */
 			str = g_strdup_printf (_("_Open with %s"),  g_app_info_get_name (list->data));
 			new1 = gtk_image_menu_item_new_with_mnemonic (str);
+			g_free (str);
 			gtk_widget_show (new1);
 
 			g_object_set_data_full (G_OBJECT (new1), "app", (GAppInfo *)list->data,
@@ -1112,6 +1081,7 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 				}
 				
 				new1 = gtk_image_menu_item_new_with_mnemonic (str);
+				g_free (str);
 				gtk_widget_show (new1);
 
 				g_object_set_data_full (G_OBJECT (new1), "app", (GAppInfo *)list->data,
@@ -1181,8 +1151,8 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 		}
 	}
 
-	/* Popup menu item: Open Folder */
-	new1 = gtk_image_menu_item_new_with_mnemonic  (_("Open _Folder"));
+	/* Popup menu item: Open Containing Folder */
+	new1 = gtk_image_menu_item_new_with_mnemonic  (_("Open Containing _Folder"));
 	gtk_container_add (GTK_CONTAINER (gsearch->search_results_popup_menu), new1);
 	gtk_widget_show (new1);
 
@@ -1579,7 +1549,7 @@ drag_file_cb  (GtkWidget * widget,
 				uri_list = g_strconcat (uri_list, "\n", tmp_uri, NULL);
 			}
 			gtk_selection_data_set (selection_data,
-			                        selection_data->target,
+			                        gtk_selection_data_get_target (selection_data),
 			                        8,
 			                        (guchar *) uri_list,
 			                        strlen (uri_list));
@@ -1646,10 +1616,6 @@ display_dialog_could_not_save_no_name (GtkWidget * window)
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          secondary, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	g_signal_connect (G_OBJECT (dialog),
 	                  "response",
 	                  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -1678,10 +1644,6 @@ display_dialog_could_not_save_to (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          message, NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	g_signal_connect (G_OBJECT (dialog),
 	                  "response",
 	                  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -1715,10 +1677,6 @@ display_dialog_could_not_save_exists (GtkWidget * window,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          secondary);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
 	button = gsearchtool_button_new_with_stock_icon (_("_Replace"), GTK_STOCK_OK);
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 	gtk_widget_show (button);
@@ -1834,7 +1792,7 @@ key_press_cb (GtkWidget * widget,
 
 	g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
-	if (event->keyval == GDK_Escape) {
+	if (event->keyval == GDK_KEY_Escape) {
 		if (gsearch->command_details->command_status == RUNNING) {
 			click_stop_cb (widget, data);
 		}
@@ -1842,7 +1800,7 @@ key_press_cb (GtkWidget * widget,
 			quit_cb (widget, (GdkEvent *) NULL, data);
 		}
 	}
-	else if (event->keyval == GDK_F10) {
+	else if (event->keyval == GDK_KEY_F10) {
 		if (event->state & GDK_SHIFT_MASK) {
 			gboolean no_files_found = FALSE;
 			GtkTreeModel * model;
